<?php
// $Id: pagestyle.block.inc,v 1.1.2.3 2009/10/01 01:42:41 christianzwahlen Exp $

/**
 * @file
 * Block, page and theme functions.
 */

/**
 * Returns an array of allowed values.
 *
 * @return
 *   An array of allowed values.
 */
function pagestyle_allowed_values() {
  $pagestyle_allowed = array(
    'black_white',
    'white_black',
    'yellow_blue',
    'standard',
  );
  return $pagestyle_allowed;
}

/**
 * Menu callback; Set the pagestyle to Black/White, then redirects to the previous page.
 */
function pagestyle_black_white() {
  $ps_name = t('Black') .'/'. t('White');
  if (!isset($_COOKIE['pagestyle'])) {
    drupal_set_message(t('The page style have not been saved, because your browser do not accept cookies.'), 'error');
  }
  else {
    $_SESSION['pagestyle'] = 'black_white';
    setcookie("pagestyle", ("black_white"), time()+31536000, "/", "");
    drupal_set_message(t('The page style have been saved as %ps_name.', array('%ps_name' => $ps_name)));
  }
  pagestyle_clear_cache();
  drupal_goto();
}

/**
 * Menu callback; Set the pagestyle to White/Black, then redirects to the previous page.
 */
function pagestyle_white_black() {
  $ps_name = t('White') .'/'. t('Black');
  if (!isset($_COOKIE['pagestyle'])) {
    drupal_set_message(t('The page style have not been saved, because your browser do not accept cookies.'), 'error');
  }
  else {
    $_SESSION['pagestyle'] = 'white_black';
    setcookie("pagestyle", ("white_black"), time()+31536000, "/", "");
    drupal_set_message(t('The page style have been saved as %ps_name.', array('%ps_name' => $ps_name)));
  }
  pagestyle_clear_cache();
  drupal_goto();
}

/**
 * Menu callback; Set the pagestyle to Yellow/Blue, then redirects to the previous page.
 */
function pagestyle_yellow_blue() {
  $ps_name = t('Yellow') .'/'. t('Blue');
  if (!isset($_COOKIE['pagestyle'])) {
    drupal_set_message(t('The page style have not been saved, because your browser do not accept cookies.'), 'error');
  }
  else {
    $_SESSION['pagestyle'] = 'yellow_blue';
    setcookie("pagestyle", ("yellow_blue"), time()+31536000, "/", "");
    drupal_set_message(t('The page style have been saved as %ps_name.', array('%ps_name' => $ps_name)));
  }
  pagestyle_clear_cache();
  drupal_goto();
}

/**
 * Menu callback; change the pagestyle to Standard, then redirects to the previous page.
 */
function pagestyle_standard() {
  $ps_name = t('Standard');
  if (!isset($_COOKIE['pagestyle'])) {
    drupal_set_message(t('The page style have not been saved, because your browser do not accept cookies.'), 'error');
  }
  else {
    $_SESSION['pagestyle'] = 'standard';
    setcookie("pagestyle", ("standard"), time()+31536000, "/", "");
    drupal_set_message(t('The page style have been saved as %ps_name.', array('%ps_name' => $ps_name)));
  }
  pagestyle_clear_cache();
  drupal_goto();
}

/**
 * Menu callback; change the pagestyle to the cookie value, then redirects to the previous page.
 */
function pagestyle_set() {
  $pagestyle_normal = variable_get('pagestyle_normal', 'standard');
  $pagestyle_text = array(
    'black_white' => t('Black') .'/'. t('White'),
    'white_black' => t('White') .'/'. t('Black'),
    'yellow_blue' => t('Yellow') .'/'. t('Blue'),
    'standard' => t('Standard'),
  );
  $pagestyle_post = array();
  $pagestyle_cookie = array();
  // allowed values
  $pagestyle_allowed = pagestyle_allowed_values();
  // check the type and the content
  if (in_array($_COOKIE['pagestyle'], $pagestyle_allowed)) {
    $pagestyle_cookie['pagestyle'] = (string) filter_xss($_COOKIE['pagestyle']);
  }
  // set session/cookie
  if (!isset($_COOKIE['pagestyle'])) {
    drupal_set_message(t('The page style have not been saved, because your browser do not accept cookies.'), 'error');
  }
  elseif (isset($_COOKIE['pagestyle'])) {
    $_SESSION['pagestyle'] = $pagestyle_cookie['pagestyle'];
    setcookie("pagestyle", $pagestyle_cookie['pagestyle'], time()+31536000, "/", "");
    drupal_set_message(t('The page style have been saved as %pagestyle.', array('%pagestyle' => $pagestyle_text[$pagestyle_cookie['pagestyle']])));
  }
  pagestyle_clear_cache();
  drupal_goto();
}

/**
 * Clear defined cache tables
 */
function pagestyle_clear_cache() {
  $tables = array(
    'cache_page',
    'cache_block',
  );
  foreach ($tables as $table) {
    cache_clear_all('*', $table, TRUE);
  }
}

/**
 * Returns an array of available values for the select element in the block page style.
 *
 * @return
 *   An array of available values, for selecting the page style.
 * @see pagestyle_form()
 */
function pagestyle_block_form_options() {
  $pagestyle_black_white = variable_get('pagestyle_black_white', 1);
  $pagestyle_white_black = variable_get('pagestyle_white_black', 1);
  $pagestyle_yellow_blue = variable_get('pagestyle_yellow_blue', 1);
  $pagestyle_standard = variable_get('pagestyle_standard', 1);
  $ps_options = array(
    $var['black_white'] = array(
      'class' => 'black_white',
      'name' => t('Black/White'),
      'display' => $pagestyle_black_white,
      ),
    $var['white_black'] = array(
      'class' => 'white_black',
      'name' => t('White/Black'),
      'display' => $pagestyle_white_black,
      ),
    $var['yellow_blue'] = array(
      'class' => 'yellow_blue',
      'name' => t('Yellow/Blue'),
      'display' => $pagestyle_yellow_blue,
      ),
    $var['standard'] = array(
      'class' => 'standard',
      'name' => t('Standard'),
      'display' => $pagestyle_standard,
      ),
    );
  $options = array();
  foreach ($ps_options as $name) {
    if ($name['display'] == 1) {
    $options[$name['class']] = $name['name'];
    }
  }
  return $options;
}

function pagestyle_form() {
  $pagestyle_normal = variable_get('pagestyle_normal', 'standard');
  $display_current_pagestyle = variable_get('pagestyle_display_current_pagestyle', '');
  $pagestyle = pagestyle_get_current($value = 'int');
  $options = pagestyle_block_form_options();
  $pagestyle_text = array(
    'black_white' => t('Black') .'/'. t('White'),
    'white_black' => t('White') .'/'. t('Black'),
    'yellow_blue' => t('Yellow') .'/'. t('Blue'),
    'standard' => t('Standard'),
  );
  $pagestyle_post = array();
  $pagestyle_cookie = array();
  // allowed values
  $pagestyle_allowed = pagestyle_allowed_values();
  // check the type and the content
  if (isset($_COOKIE['pagestyle']) && isset($_POST['pagestyle_select'])) {
    if (in_array($_POST['pagestyle_select'], $pagestyle_allowed)) {
      $pagestyle_post['pagestyle'] = (string) filter_xss($_POST['pagestyle_select']);
    }
    // set session/cookie
    setcookie("pagestyle", $pagestyle_post['pagestyle'], time()+31536000, "/", "");
    $_SESSION['pagestyle'] = $pagestyle_post['pagestyle'];
    drupal_set_message(t('The page style have been saved as %pagestyle_post.', array('%pagestyle_post' => $pagestyle_text[$pagestyle_post['pagestyle']])));
    pagestyle_clear_cache();
  }
  elseif (!isset($_COOKIE['pagestyle']) && isset($_POST['pagestyle_select'])) {
    drupal_set_message(t('The page style have not been saved, because your browser do not accept cookies.'), 'error');
  }
  $form = array();
  $form['pagestyle_select'] = array(
    '#type' => 'select',
  // '#title' => t('Page Style'),
    '#name' => 'pagestyle_select',
    '#options' => $options,
    '#default_value' => variable_get('pagestyle_select', $pagestyle),
    '#weight' => 0,
  //'#description' => t('Select the page style.'),
  );
  $form['pagestyle_submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
    '#weight' => 1,
  );
  $form['#skip_duplicate_check'] = TRUE;
  return $form;
}

/**
 * Implementation of theme().
 *
 * @see pagestyle_form()
 */
function theme_pagestyle_form($form) {
  $output = drupal_render($form);
  return $output;
}

/**
 * Implementation of hook_theme().
 */
function pagestyle_theme() {
  $arguments = array(
    'dest' => NULL,
    'list_inline' => NULL,
    'link_type' => NULL,
    'display_links' => NULL,
    'black_white' => NULL,
    'white_black' => NULL,
    'yellow_blue' => NULL,
    'standard' => NULL,
    'display_current_pagestyle' => NULL,
    'pagestyle' => NULL,
  );
  return array(
    'pagestyle_text' => array(
      'template' => 'pagestyle-text',
      'arguments' => $arguments,
    ),
    'pagestyle_image' => array(
      'template' => 'pagestyle-image',
      'arguments' => $arguments,
    ),
    'pagestyle_form' => array(
      'template' => 'pagestyle-form',
      'arguments' => array(
        'form' => NULL,
        'pagestyle_form' => NULL,
        'display_current_pagestyle' => NULL,
        'pagestyle' => NULL,
      )
    ),
  );
}

/**
 * Process variables for pagestyle-text.tpl.php.
 *
 * The $variables array contains the following arguments:
 * - $dest: The drupal function drupal_get_destination().
 * - $list_inline: Display the ul list "inline" or not.
 * - $display_links: Show or hide ("display_hidden") the text in the links.
 * - $black_white: The pagestyle Black/White "black_white".
 * - $white_black: The pagestyle Black/White "white_black".
 * - $yellow_blue: The pagestyle Black/White "yellow_blue".
 * - $standard: The pagestyle Standard "standard".
 * - $display_current_pagestyle: Show or hide ("display_hidden") the text of the current pagestyle.
 * - $pagestyle: The current page style (default Standard).
 *
 * @see pagestyle_theme(), pagestyle-text.tpl.php
 */
function template_preprocess_pagestyle_text(&$variables) {
  $pagestyle_block_type = variable_get('pagestyle_block_type', 'text');
  $pagestyle_black_white = variable_get('pagestyle_black_white', 1);
  $pagestyle_white_black = variable_get('pagestyle_white_black', 1);
  $pagestyle_yellow_blue = variable_get('pagestyle_yellow_blue', 1);
  $pagestyle_standard = variable_get('pagestyle_standard', 1);
  if (isset($variables['block'])) {
    $variables['template_files'][] = 'pagestyle-text';
  }
  if ($pagestyle_black_white == 1) {
    $variables['black_white'] = "black_white";
  }
  if ($pagestyle_white_black == 1) {
    $variables['white_black'] = "white_black";
  }
  if ($pagestyle_yellow_blue == 1) {
    $variables['yellow_blue'] = "yellow_blue";
  }
  if ($pagestyle_standard == 1) {
    $variables['standard'] = "standard";
  }
  $variables['dest'] = drupal_get_destination();
  $variables['block_'. $pagestyle_block_type] = 'block_'. $pagestyle_block_type;
  $variables['list_inline'] = variable_get('pagestyle_list_inline', 'list');
  $variables['display_links'] = variable_get('pagestyle_display_links', '');
  $variables['display_current_pagestyle'] = variable_get('pagestyle_display_current_pagestyle', '');
  $variables['pagestyle'] = pagestyle_get_current($value = 'name');
}

/**
 * Process variables for pagestyle-image.tpl.php.
 *
 * The $variables array contains the following arguments:
 * - $dest: The drupal function drupal_get_destination().
 * - $list_inline: Display the ul list "inline" or not.
 * - $display_links: Show or hide ("display_hidden") the text in the links.
 * - $black_white: The pagestyle Black/White "black_white".
 * - $white_black: The pagestyle Black/White "white_black".
 * - $yellow_blue: The pagestyle Black/White "yellow_blue".
 * - $standard: The pagestyle Standard "standard".
 * - $display_current_pagestyle: Show or hide ("display_hidden") the text of the current pagestyle.
 * - $pagestyle: The current page style (default Standard).
 *
 * @see pagestyle_theme(), pagestyle-image.tpl.php
 */
function template_preprocess_pagestyle_image(&$variables) {
  $pagestyle_block_type = variable_get('pagestyle_block_type', 'text');
  $pagestyle_black_white = variable_get('pagestyle_black_white', 1);
  $pagestyle_white_black = variable_get('pagestyle_white_black', 1);
  $pagestyle_yellow_blue = variable_get('pagestyle_yellow_blue', 1);
  $pagestyle_standard = variable_get('pagestyle_standard', 1);
  if (isset($variables['block'])) {
    $variables['template_files'][] = 'pagestyle-image';
  }
  if ($pagestyle_black_white == 1) {
    $variables['black_white'] = "black_white";
  }
  if ($pagestyle_white_black == 1) {
    $variables['white_black'] = "white_black";
  }
  if ($pagestyle_yellow_blue == 1) {
    $variables['yellow_blue'] = "yellow_blue";
  }
  if ($pagestyle_standard == 1) {
    $variables['standard'] = "standard";
  }
  $variables['dest'] = drupal_get_destination();
  $variables['block_'. $pagestyle_block_type] = 'block_'. $pagestyle_block_type;
  $variables['list_inline'] = variable_get('pagestyle_list_inline', 'list');
  $variables['display_links'] = variable_get('pagestyle_display_links', '');
  $variables['display_current_pagestyle'] = variable_get('pagestyle_display_current_pagestyle', '');
  $variables['pagestyle'] = pagestyle_get_current($value = 'name');
}

/**
 * Process variables for pagestyle-form.tpl.php.
 *
 * The $variables array contains the following arguments:
 * - $pagestyle_form: The form.
 * - $display_current_pagestyle: Show or hide ("display_hidden") the text of the current pagestyle.
 * - $pagestyle: The current page style (default 100%).
 *
 * @see pagestyle_theme(), pagestyle-form.tpl.php
 */
function template_preprocess_pagestyle_form(&$variables) {
  $variables['pagestyle'] = array();
  $hidden = array();
  // Provide variables named after form keys so themers can print each element independently.
  foreach (element_children($variables['form']) as $key) {
    $type = $variables['form'][$key]['#type'];
    if ($type == 'hidden' || $type == 'token') {
      $hidden[] = drupal_render($variables['form'][$key]);
    }
    else {
      $variables['pagestyle'][$key] = drupal_render($variables['form'][$key]);
    }
  }
  // Hidden form elements have no value to themers. No need for separation.
  $variables['pagestyle']['hidden'] = implode($hidden);
  // Collect all form elements to make it easier to print the whole form.
  $variables['pagestyle_form'] = implode($variables['pagestyle']);
  $variables['display_current_pagestyle'] = variable_get('pagestyle_display_current_pagestyle', '');
  $variables['pagestyle'] = pagestyle_get_current($value = 'name');
}
